"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import qwak.administration.v0.users.user_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UserProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    JOB_FUNCTION_FIELD_NUMBER: builtins.int
    JOB_LEVEL_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """User ID"""
    @property
    def display_name(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Display user name"""
    job_function: qwak.administration.v0.users.user_pb2.QwakUserJobFunction.ValueType
    """Job function"""
    job_level: qwak.administration.v0.users.user_pb2.QwakUserJobLevel.ValueType
    """Job level"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User bound environments"""
    time_zone: builtins.str
    """Time zone"""
    def __init__(
        self,
        *,
        id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        display_name: google.protobuf.wrappers_pb2.StringValue | None = ...,
        job_function: qwak.administration.v0.users.user_pb2.QwakUserJobFunction.ValueType = ...,
        job_level: qwak.administration.v0.users.user_pb2.QwakUserJobLevel.ValueType = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_role", b"account_role", "display_name", b"display_name", "environment_ids", b"environment_ids", "id", b"id", "job_function", b"job_function", "job_level", b"job_level", "time_zone", b"time_zone"]) -> None: ...

global___UserProfile = UserProfile
