"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DatabricksAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    DB_PRINCIPAL_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def db_access_token(self) -> global___DatabricksAccessToken: ...
    @property
    def db_principal_credentials(self) -> global___DatabricksServicePrincipalCredentials: ...
    def __init__(
        self,
        *,
        db_access_token: global___DatabricksAccessToken | None = ...,
        db_principal_credentials: global___DatabricksServicePrincipalCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "db_access_token", b"db_access_token", "db_principal_credentials", b"db_principal_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "db_access_token", b"db_access_token", "db_principal_credentials", b"db_principal_credentials"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["db_access_token", "db_principal_credentials"] | None: ...

global___DatabricksAuth = DatabricksAuth

class DatabricksServicePrincipalCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DB_WORKSPACE_DESCRIPTOR_FIELD_NUMBER: builtins.int
    @property
    def client_id(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    @property
    def client_secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    @property
    def db_workspace_descriptor(self) -> global___DatabricksWorkspaceDescriptor: ...
    def __init__(
        self,
        *,
        client_id: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
        client_secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
        db_workspace_descriptor: global___DatabricksWorkspaceDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_id_location", b"client_id_location", "client_secret", b"client_secret", "client_secret_location", b"client_secret_location", "db_workspace_descriptor", b"db_workspace_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_id_location", b"client_id_location", "client_secret", b"client_secret", "client_secret_location", b"client_secret_location", "db_workspace_descriptor", b"db_workspace_descriptor"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["client_id_location", b"client_id_location"]) -> typing_extensions.Literal["client_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["client_secret_location", b"client_secret_location"]) -> typing_extensions.Literal["client_secret"] | None: ...

global___DatabricksServicePrincipalCredentials = DatabricksServicePrincipalCredentials

class DatabricksWorkspaceDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_SERVICE_URL_FIELD_NUMBER: builtins.int
    oauth_service_url: builtins.str
    def __init__(
        self,
        *,
        oauth_service_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oauth_service_url", b"oauth_service_url"]) -> None: ...

global___DatabricksWorkspaceDescriptor = DatabricksWorkspaceDescriptor

class DatabricksAccessToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["secret"] | None: ...

global___DatabricksAccessToken = DatabricksAccessToken
