"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class VictoriaMetricsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMXY_FIELD_NUMBER: builtins.int
    @property
    def promxy(self) -> qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2.PromxyConfiguration: ...
    def __init__(
        self,
        *,
        promxy: qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2.PromxyConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["promxy", b"promxy", "proxy_type", b"proxy_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["promxy", b"promxy", "proxy_type", b"proxy_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["proxy_type", b"proxy_type"]) -> typing_extensions.Literal["promxy"] | None: ...

global___VictoriaMetricsConfiguration = VictoriaMetricsConfiguration
