# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/inference/feedback/feedback.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/inference/feedback/feedback.proto\x12\x18\x63om.qwak.ai.feedback.api\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbc\x01\n\x13\x41\x63tualValuesRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x30\n\x06\x65ntity\x18\x02 \x01(\x0b\x32 .com.qwak.ai.feedback.api.Entity\x12\x32\n\x07\x61\x63tuals\x18\x03 \x01(\x0b\x32!.com.qwak.ai.feedback.api.Actuals\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xde\x01\n\x18\x45nrichedActualValuesData\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x30\n\x06\x65ntity\x18\x02 \x01(\x0b\x32 .com.qwak.ai.feedback.api.Entity\x12\x32\n\x07\x61\x63tuals\x18\x03 \x01(\x0b\x32!.com.qwak.ai.feedback.api.Actuals\x12\x1b\n\x13qwak_environment_id\x18\x04 \x01(\t\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"%\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"%\n\x07\x41\x63tuals\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"\x98\x01\n\x14\x41\x63tualValuesResponse\x12J\n\x06status\x18\x01 \x01(\x0e\x32:.com.qwak.ai.feedback.api.ActualValuesResponse.ValueStatus\"4\n\x0bValueStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\"\xf1\x02\n\x18\x43onfigureFeedbackRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x1f\n\x17\x61nalytics_entity_column\x18\x02 \x01(\t\x12\x1e\n\x16\x66\x65\x65\x64\x62\x61\x63k_entity_column\x18\x03 \x01(\t\x12\x41\n\x0f\x66\x65\x65\x64\x62\x61\x63k_config\x18\x04 \x03(\x0b\x32(.com.qwak.ai.feedback.api.FeedbackConfig\x12P\n\nmodel_type\x18\x05 \x01(\x0e\x32<.com.qwak.ai.feedback.api.ConfigureFeedbackRequest.ModelType\"m\n\tModelType\x12\x16\n\x12INVALID_MODEL_TYPE\x10\x00\x12\x19\n\x15\x42INARY_CLASSIFICATION\x10\x01\x12\x1d\n\x19MULTICLASS_CLASSIFICATION\x10\x02\x12\x0e\n\nREGRESSION\x10\x03\";\n\x0e\x46\x65\x65\x64\x62\x61\x63kConfig\x12\x15\n\routput_column\x18\x01 \x01(\t\x12\x12\n\nactual_tag\x18\x02 \x01(\t\"\xa2\x01\n\x19\x43onfigureFeedbackResponse\x12O\n\x06status\x18\x01 \x01(\x0e\x32?.com.qwak.ai.feedback.api.ConfigureFeedbackResponse.ValueStatus\"4\n\x0bValueStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x32\xfe\x01\n\x0f\x46\x65\x65\x64\x62\x61\x63kService\x12m\n\x0cPostFeedback\x12-.com.qwak.ai.feedback.api.ActualValuesRequest\x1a..com.qwak.ai.feedback.api.ActualValuesResponse\x12|\n\x11\x43onfigureFeedback\x12\x32.com.qwak.ai.feedback.api.ConfigureFeedbackRequest\x1a\x33.com.qwak.ai.feedback.api.ConfigureFeedbackResponseB\x1a\n\x18\x63om.qwak.ai.feedback.apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.inference.feedback.feedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.qwak.ai.feedback.api'
  _globals['_ACTUALVALUESREQUEST']._serialized_start=102
  _globals['_ACTUALVALUESREQUEST']._serialized_end=290
  _globals['_ENRICHEDACTUALVALUESDATA']._serialized_start=293
  _globals['_ENRICHEDACTUALVALUESDATA']._serialized_end=515
  _globals['_ENTITY']._serialized_start=517
  _globals['_ENTITY']._serialized_end=554
  _globals['_ACTUALS']._serialized_start=556
  _globals['_ACTUALS']._serialized_end=593
  _globals['_ACTUALVALUESRESPONSE']._serialized_start=596
  _globals['_ACTUALVALUESRESPONSE']._serialized_end=748
  _globals['_ACTUALVALUESRESPONSE_VALUESTATUS']._serialized_start=696
  _globals['_ACTUALVALUESRESPONSE_VALUESTATUS']._serialized_end=748
  _globals['_CONFIGUREFEEDBACKREQUEST']._serialized_start=751
  _globals['_CONFIGUREFEEDBACKREQUEST']._serialized_end=1120
  _globals['_CONFIGUREFEEDBACKREQUEST_MODELTYPE']._serialized_start=1011
  _globals['_CONFIGUREFEEDBACKREQUEST_MODELTYPE']._serialized_end=1120
  _globals['_FEEDBACKCONFIG']._serialized_start=1122
  _globals['_FEEDBACKCONFIG']._serialized_end=1181
  _globals['_CONFIGUREFEEDBACKRESPONSE']._serialized_start=1184
  _globals['_CONFIGUREFEEDBACKRESPONSE']._serialized_end=1346
  _globals['_CONFIGUREFEEDBACKRESPONSE_VALUESTATUS']._serialized_start=696
  _globals['_CONFIGUREFEEDBACKRESPONSE_VALUESTATUS']._serialized_end=748
  _globals['_FEEDBACKSERVICE']._serialized_start=1349
  _globals['_FEEDBACKSERVICE']._serialized_end=1603
# @@protoc_insertion_point(module_scope)
