# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/logging/log_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/logging/log_filter.proto\x12\x14qwak.logging.service\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x01\n\x0cSearchFilter\x12\x38\n\x0flog_text_filter\x18\x01 \x01(\x0b\x32\x1d.qwak.logging.service.LogTextH\x00\x12\x46\n\x13\x61nd_operator_filter\x18\x02 \x01(\x0b\x32\'.qwak.logging.service.AndOperatorFilterH\x00\x12G\n\x18log_emitting_time_filter\x18\x03 \x01(\x0b\x32#.qwak.logging.service.LogTimeFilterH\x00\x42\x08\n\x06\x66ilter\"\x1b\n\x07LogText\x12\x10\n\x08\x63ontains\x18\x01 \x01(\t\"p\n\rLogTimeFilter\x12.\n\nafter_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x62\x65\x66ore_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\x11\x41ndOperatorFilter\x12:\n\x0esearch_filters\x18\x01 \x03(\x0b\x32\".qwak.logging.service.SearchFilterB,\n\x1e\x63om.qwak.ai.logging.reader.apiP\x01Z\x08/loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.logging.log_filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.logging.reader.apiP\001Z\010/logging'
  _globals['_SEARCHFILTER']._serialized_start=89
  _globals['_SEARCHFILTER']._serialized_end=316
  _globals['_LOGTEXT']._serialized_start=318
  _globals['_LOGTEXT']._serialized_end=345
  _globals['_LOGTIMEFILTER']._serialized_start=347
  _globals['_LOGTIMEFILTER']._serialized_end=459
  _globals['_ANDOPERATORFILTER']._serialized_start=461
  _globals['_ANDOPERATORFILTER']._serialized_end=540
# @@protoc_insertion_point(module_scope)
