"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountAcceptedTerms(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TERMS_FIELD_NUMBER: builtins.int
    @property
    def terms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Term]:
        """Account accepted terms"""
    def __init__(
        self,
        *,
        terms: collections.abc.Iterable[global___Term] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["terms", b"terms"]) -> None: ...

global___AccountAcceptedTerms = AccountAcceptedTerms

class Term(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_GENERAL_TERM_FIELD_NUMBER: builtins.int
    MODEL_LIBRARY_GENERAL_TERM_FIELD_NUMBER: builtins.int
    MODEL_LIBRARY_MODEL_TERM_FIELD_NUMBER: builtins.int
    @property
    def platform_general_term(self) -> global___PlatformGeneralTerm:
        """Platform general term"""
    @property
    def model_library_general_term(self) -> global___ModelLibraryGeneralTerm:
        """Model library general term"""
    @property
    def model_library_model_term(self) -> global___ModelLibraryModelTerm:
        """Model library model term"""
    def __init__(
        self,
        *,
        platform_general_term: global___PlatformGeneralTerm | None = ...,
        model_library_general_term: global___ModelLibraryGeneralTerm | None = ...,
        model_library_model_term: global___ModelLibraryModelTerm | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_library_general_term", b"model_library_general_term", "model_library_model_term", b"model_library_model_term", "platform_general_term", b"platform_general_term", "term", b"term"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_library_general_term", b"model_library_general_term", "model_library_model_term", b"model_library_model_term", "platform_general_term", b"platform_general_term", "term", b"term"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["term", b"term"]) -> typing_extensions.Literal["platform_general_term", "model_library_general_term", "model_library_model_term"] | None: ...

global___Term = Term

class PlatformGeneralTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PlatformGeneralTerm = PlatformGeneralTerm

class ModelLibraryGeneralTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ModelLibraryGeneralTerm = ModelLibraryGeneralTerm

class ModelLibraryModelTerm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_REGISTRY_ID_FIELD_NUMBER: builtins.int
    model_registry_id: builtins.str
    """The id of the model registry"""
    def __init__(
        self,
        *,
        model_registry_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_registry_id", b"model_registry_id"]) -> None: ...

global___ModelLibraryModelTerm = ModelLibraryModelTerm
