"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.ecosystem.v0.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AzureTemporaryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_DATABRICKS_SERVICE_TEMPORARY_CREDENTIALS_FIELD_NUMBER: builtins.int
    DATABRICKS_CREDENTIALS_FIELD_NUMBER: builtins.int
    AZURE_STORAGE_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def azure_databricks_service_temporary_credentials(self) -> global___AzureDatabricksServiceTemporaryCredentials: ...
    @property
    def databricks_credentials(self) -> global___DatabricksCredentials: ...
    @property
    def azure_storage_credentials(self) -> global___AzureStorageCredentials: ...
    def __init__(
        self,
        *,
        azure_databricks_service_temporary_credentials: global___AzureDatabricksServiceTemporaryCredentials | None = ...,
        databricks_credentials: global___DatabricksCredentials | None = ...,
        azure_storage_credentials: global___AzureStorageCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_databricks_service_temporary_credentials", b"azure_databricks_service_temporary_credentials", "azure_storage_credentials", b"azure_storage_credentials", "databricks_credentials", b"databricks_credentials", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_databricks_service_temporary_credentials", b"azure_databricks_service_temporary_credentials", "azure_storage_credentials", b"azure_storage_credentials", "databricks_credentials", b"databricks_credentials", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["azure_databricks_service_temporary_credentials", "databricks_credentials", "azure_storage_credentials"] | None: ...

global___AzureTemporaryCredentials = AzureTemporaryCredentials

class AzureDatabricksServiceTemporaryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABRICKS_CREDENTIALS_FIELD_NUMBER: builtins.int
    AZURE_STORAGE_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def databricks_credentials(self) -> global___DatabricksCredentials: ...
    @property
    def azure_storage_credentials(self) -> global___AzureStorageCredentials: ...
    def __init__(
        self,
        *,
        databricks_credentials: global___DatabricksCredentials | None = ...,
        azure_storage_credentials: global___AzureStorageCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_storage_credentials", b"azure_storage_credentials", "databricks_credentials", b"databricks_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_storage_credentials", b"azure_storage_credentials", "databricks_credentials", b"databricks_credentials"]) -> None: ...

global___AzureDatabricksServiceTemporaryCredentials = AzureDatabricksServiceTemporaryCredentials

class DatabricksCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_TOKEN_CREDENTIAL_FIELD_NUMBER: builtins.int
    @property
    def oauth_token_credential(self) -> qwak.ecosystem.v0.auth_pb2.OAuthTokenCredential: ...
    def __init__(
        self,
        *,
        oauth_token_credential: qwak.ecosystem.v0.auth_pb2.OAuthTokenCredential | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["oauth_token_credential", b"oauth_token_credential", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["oauth_token_credential", b"oauth_token_credential", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["oauth_token_credential"] | None: ...

global___DatabricksCredentials = DatabricksCredentials

class AzureStorageCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAS_TOKEN_CREDENTIAL_FIELD_NUMBER: builtins.int
    @property
    def sas_token_credential(self) -> global___SASTokenCredentials: ...
    def __init__(
        self,
        *,
        sas_token_credential: global___SASTokenCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sas_token_credential", b"sas_token_credential", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sas_token_credential", b"sas_token_credential", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["sas_token_credential"] | None: ...

global___AzureStorageCredentials = AzureStorageCredentials

class SASTokenCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    EXPIRED_AT_FIELD_NUMBER: builtins.int
    token: builtins.str
    """The token to use for authentication"""
    @property
    def expired_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expiration timestamp of the credentials"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        expired_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at", "token", b"token"]) -> None: ...

global___SASTokenCredentials = SASTokenCredentials
