# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/v0/ecosystem_runtime_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.ecosystem.v0 import ecosystem_pb2 as qwak_dot_ecosystem_dot_v0_dot_ecosystem__pb2
from _qwak_proto.qwak.ecosystem.v0 import credentials_pb2 as qwak_dot_ecosystem_dot_v0_dot_credentials__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/ecosystem/v0/ecosystem_runtime_service.proto\x12\x11qwak.ecosystem.v0\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!qwak/ecosystem/v0/ecosystem.proto\x1a#qwak/ecosystem/v0/credentials.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc1\x01\n\x13\x41uthenticateRequest\x12M\n\x18username_password_method\x18\x01 \x01(\x0b\x32).qwak.ecosystem.v0.UsernamePasswordMethodH\x00\x12\x42\n\x13qwak_api_key_method\x18\x02 \x01(\x0b\x32#.qwak.ecosystem.v0.QwakApiKeyMethodH\x00\x42\x17\n\x15\x61uthentication_method\"\\\n\x14\x41uthenticateResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"$\n\"GetAuthenticatedUserContextRequest\"v\n#GetAuthenticatedUserContextResponse\x12O\n\x1a\x61uthenticated_user_context\x18\x01 \x01(\x0b\x32+.qwak.ecosystem.v0.AuthenticatedUserContext\"C\n\x1cGetUnifiedUserContextRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"b\n\x1dGetUnifiedUserContextResponse\x12\x41\n\x0cuser_context\x18\x01 \x01(\x0b\x32+.qwak.ecosystem.v0.AuthenticatedUserContext\"M\n\x11GetAccountRequest\x12\x14\n\naccount_id\x18\x01 \x01(\tH\x00\x12\x18\n\x0e\x65nvironment_id\x18\x02 \x01(\tH\x00\x42\x08\n\x06get_by\"P\n\x12GetAccountResponse\x12:\n\x0f\x61\x63\x63ount_details\x18\x01 \x01(\x0b\x32!.qwak.ecosystem.v0.AccountDetails\"\x19\n\x17ListUserAccountsRequest\"Y\n\x18ListUserAccountsResponse\x12=\n\x11user_account_list\x18\x01 \x01(\x0b\x32\".qwak.ecosystem.v0.UserAccountList\"b\n\x1aGetCloudCredentialsRequest\x12\x44\n\nparameters\x18\x01 \x01(\x0b\x32\x30.qwak.ecosystem.v0.GetCloudCredentialsParameters\"\x86\x01\n\x1dGetCloudCredentialsParameters\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x0epermission_set\x18\x02 \x01(\x0b\x32 .qwak.ecosystem.v0.PermissionSet\"\xb0\x05\n\rPermissionSet\x12S\n\x19\x65\x64ge_environment_workload\x18\x01 \x01(\x0b\x32*.qwak.ecosystem.v0.EdgeEnvironmentWorkloadB\x02\x18\x01H\x00\x12\x38\n\rcore_services\x18\x02 \x01(\x0b\x32\x1f.qwak.ecosystem.v0.CoreServicesH\x00\x12T\n\x1coffline_feature_store_client\x18\x03 \x01(\x0b\x32,.qwak.ecosystem.v0.OfflineFeatureStoreClientH\x00\x12G\n\x15remote_build_executor\x18\x04 \x01(\x0b\x32&.qwak.ecosystem.v0.RemoteBuildExecutorH\x00\x12X\n\x1epull_models_container_registry\x18\x05 \x01(\x0b\x32..qwak.ecosystem.v0.PullModelsContainerRegistryH\x00\x12\x41\n\x12\x62\x61tch_job_executor\x18\x06 \x01(\x0b\x32#.qwak.ecosystem.v0.BatchJobExecutorH\x00\x12G\n\x15\x66\x65\x61ture_set_processor\x18\x07 \x01(\x0b\x32&.qwak.ecosystem.v0.FeatureSetProcessorH\x00\x12@\n\x11\x61nalytics_service\x18\x08 \x01(\x0b\x32#.qwak.ecosystem.v0.AnalyticsServiceH\x00\x12>\n\x10\x61nalytics_client\x18\t \x01(\x0b\x32\".qwak.ecosystem.v0.AnalyticsClientH\x00\x42\t\n\x07subject\"1\n\x17\x45\x64geEnvironmentWorkload\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"&\n\x0c\x43oreServices\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"3\n\x19OfflineFeatureStoreClient\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"-\n\x13RemoteBuildExecutor\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"5\n\x1bPullModelsContainerRegistry\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"*\n\x10\x42\x61tchJobExecutor\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"-\n\x13\x46\x65\x61tureSetProcessor\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"*\n\x10\x41nalyticsService\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\")\n\x0f\x41nalyticsClient\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"]\n\x1bGetCloudCredentialsResponse\x12>\n\x11\x63loud_credentials\x18\x01 \x01(\x0b\x32#.qwak.ecosystem.v0.CloudCredentials2\xc0\x05\n\x14QwakEcosystemRuntime\x12_\n\x0c\x41uthenticate\x12&.qwak.ecosystem.v0.AuthenticateRequest\x1a\'.qwak.ecosystem.v0.AuthenticateResponse\x12\x8c\x01\n\x1bGetAuthenticatedUserContext\x12\x35.qwak.ecosystem.v0.GetAuthenticatedUserContextRequest\x1a\x36.qwak.ecosystem.v0.GetAuthenticatedUserContextResponse\x12k\n\x10ListUserAccounts\x12*.qwak.ecosystem.v0.ListUserAccountsRequest\x1a+.qwak.ecosystem.v0.ListUserAccountsResponse\x12Y\n\nGetAccount\x12$.qwak.ecosystem.v0.GetAccountRequest\x1a%.qwak.ecosystem.v0.GetAccountResponse\x12t\n\x13GetCloudCredentials\x12-.qwak.ecosystem.v0.GetCloudCredentialsRequest\x1a..qwak.ecosystem.v0.GetCloudCredentialsResponse\x12z\n\x15GetUnifiedUserContext\x12/.qwak.ecosystem.v0.GetUnifiedUserContextRequest\x1a\x30.qwak.ecosystem.v0.GetUnifiedUserContextResponseB\xb7\x01\n\x1c\x63om.qwak.ai.common.ecosystemP\x01Z\x94\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.v0.ecosystem_runtime_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.qwak.ai.common.ecosystemP\001Z\224\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0'
  _PERMISSIONSET.fields_by_name['edge_environment_workload']._options = None
  _PERMISSIONSET.fields_by_name['edge_environment_workload']._serialized_options = b'\030\001'
  _globals['_AUTHENTICATEREQUEST']._serialized_start=210
  _globals['_AUTHENTICATEREQUEST']._serialized_end=403
  _globals['_AUTHENTICATERESPONSE']._serialized_start=405
  _globals['_AUTHENTICATERESPONSE']._serialized_end=497
  _globals['_GETAUTHENTICATEDUSERCONTEXTREQUEST']._serialized_start=499
  _globals['_GETAUTHENTICATEDUSERCONTEXTREQUEST']._serialized_end=535
  _globals['_GETAUTHENTICATEDUSERCONTEXTRESPONSE']._serialized_start=537
  _globals['_GETAUTHENTICATEDUSERCONTEXTRESPONSE']._serialized_end=655
  _globals['_GETUNIFIEDUSERCONTEXTREQUEST']._serialized_start=657
  _globals['_GETUNIFIEDUSERCONTEXTREQUEST']._serialized_end=724
  _globals['_GETUNIFIEDUSERCONTEXTRESPONSE']._serialized_start=726
  _globals['_GETUNIFIEDUSERCONTEXTRESPONSE']._serialized_end=824
  _globals['_GETACCOUNTREQUEST']._serialized_start=826
  _globals['_GETACCOUNTREQUEST']._serialized_end=903
  _globals['_GETACCOUNTRESPONSE']._serialized_start=905
  _globals['_GETACCOUNTRESPONSE']._serialized_end=985
  _globals['_LISTUSERACCOUNTSREQUEST']._serialized_start=987
  _globals['_LISTUSERACCOUNTSREQUEST']._serialized_end=1012
  _globals['_LISTUSERACCOUNTSRESPONSE']._serialized_start=1014
  _globals['_LISTUSERACCOUNTSRESPONSE']._serialized_end=1103
  _globals['_GETCLOUDCREDENTIALSREQUEST']._serialized_start=1105
  _globals['_GETCLOUDCREDENTIALSREQUEST']._serialized_end=1203
  _globals['_GETCLOUDCREDENTIALSPARAMETERS']._serialized_start=1206
  _globals['_GETCLOUDCREDENTIALSPARAMETERS']._serialized_end=1340
  _globals['_PERMISSIONSET']._serialized_start=1343
  _globals['_PERMISSIONSET']._serialized_end=2031
  _globals['_EDGEENVIRONMENTWORKLOAD']._serialized_start=2033
  _globals['_EDGEENVIRONMENTWORKLOAD']._serialized_end=2082
  _globals['_CORESERVICES']._serialized_start=2084
  _globals['_CORESERVICES']._serialized_end=2122
  _globals['_OFFLINEFEATURESTORECLIENT']._serialized_start=2124
  _globals['_OFFLINEFEATURESTORECLIENT']._serialized_end=2175
  _globals['_REMOTEBUILDEXECUTOR']._serialized_start=2177
  _globals['_REMOTEBUILDEXECUTOR']._serialized_end=2222
  _globals['_PULLMODELSCONTAINERREGISTRY']._serialized_start=2224
  _globals['_PULLMODELSCONTAINERREGISTRY']._serialized_end=2277
  _globals['_BATCHJOBEXECUTOR']._serialized_start=2279
  _globals['_BATCHJOBEXECUTOR']._serialized_end=2321
  _globals['_FEATURESETPROCESSOR']._serialized_start=2323
  _globals['_FEATURESETPROCESSOR']._serialized_end=2368
  _globals['_ANALYTICSSERVICE']._serialized_start=2370
  _globals['_ANALYTICSSERVICE']._serialized_end=2412
  _globals['_ANALYTICSCLIENT']._serialized_start=2414
  _globals['_ANALYTICSCLIENT']._serialized_end=2455
  _globals['_GETCLOUDCREDENTIALSRESPONSE']._serialized_start=2457
  _globals['_GETCLOUDCREDENTIALSRESPONSE']._serialized_end=2550
  _globals['_QWAKECOSYSTEMRUNTIME']._serialized_start=2553
  _globals['_QWAKECOSYSTEMRUNTIME']._serialized_end=3257
# @@protoc_insertion_point(module_scope)
