# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.cluster.v2 import cluster_service_pb2 as qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2


class ClusterServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateClusterCreationRequest = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/CreateClusterCreationRequest',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestResponse.FromString,
                )
        self.GetClusterState = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/GetClusterState',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateResponse.FromString,
                )
        self.UpdateClusterConfiguration = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/UpdateClusterConfiguration',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationResponse.FromString,
                )
        self.DeleteCluster = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/DeleteCluster',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterResponse.FromString,
                )
        self.GetCluster = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/GetCluster',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterResponse.FromString,
                )
        self.ListClusters = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/ListClusters',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersResponse.FromString,
                )


class ClusterServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateClusterCreationRequest(self, request, context):
        """Create a Cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterState(self, request, context):
        """Get Cluster state by request id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClusterConfiguration(self, request, context):
        """Update a Cluster by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCluster(self, request, context):
        """Delete Cluster by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCluster(self, request, context):
        """Get cluster by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClusters(self, request, context):
        """List all clusters by filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateClusterCreationRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClusterCreationRequest,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestResponse.SerializeToString,
            ),
            'GetClusterState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterState,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateResponse.SerializeToString,
            ),
            'UpdateClusterConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClusterConfiguration,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationResponse.SerializeToString,
            ),
            'DeleteCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCluster,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterResponse.SerializeToString,
            ),
            'GetCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCluster,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterResponse.SerializeToString,
            ),
            'ListClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClusters,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.cluster.v2.ClusterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClusterService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateClusterCreationRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/CreateClusterCreationRequest',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusterState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/GetClusterState',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateClusterConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/UpdateClusterConfiguration',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/DeleteCluster',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/GetCluster',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/ListClusters',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
