"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.cluster.v2.cluster_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateClusterCreationRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_SPEC_FIELD_NUMBER: builtins.int
    @property
    def cluster_spec(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterSpec:
        """The cluster to create"""
    def __init__(
        self,
        *,
        cluster_spec: qwak.administration.cluster.v2.cluster_pb2.ClusterSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_spec", b"cluster_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_spec", b"cluster_spec"]) -> None: ...

global___CreateClusterCreationRequestRequest = CreateClusterCreationRequestRequest

class CreateClusterCreationRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___CreateClusterCreationRequestResponse = CreateClusterCreationRequestResponse

class GetClusterStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___GetClusterStateRequest = GetClusterStateRequest

class GetClusterStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_STATE_FIELD_NUMBER: builtins.int
    @property
    def cluster_state(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterState: ...
    def __init__(
        self,
        *,
        cluster_state: qwak.administration.cluster.v2.cluster_pb2.ClusterState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> None: ...

global___GetClusterStateResponse = GetClusterStateResponse

class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The cluster id to get"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

class GetClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_STATE_FIELD_NUMBER: builtins.int
    @property
    def cluster_state(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterState: ...
    def __init__(
        self,
        *,
        cluster_state: qwak.administration.cluster.v2.cluster_pb2.ClusterState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> None: ...

global___GetClusterResponse = GetClusterResponse

class UpdateClusterConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CLUSTER_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The cluster id to update"""
    @property
    def cluster_spec(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterSpec:
        """The updated spec of the cluster"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        cluster_spec: qwak.administration.cluster.v2.cluster_pb2.ClusterSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_spec", b"cluster_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "cluster_spec", b"cluster_spec"]) -> None: ...

global___UpdateClusterConfigurationRequest = UpdateClusterConfigurationRequest

class UpdateClusterConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___UpdateClusterConfigurationResponse = UpdateClusterConfigurationResponse

class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The cluster id to delete"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

class DeleteClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___DeleteClusterResponse = DeleteClusterResponse

class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListClustersRequest = ListClustersRequest

class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.cluster.v2.cluster_pb2.Cluster]: ...
    def __init__(
        self,
        *,
        cluster: collections.abc.Iterable[qwak.administration.cluster.v2.cluster_pb2.Cluster] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___ListClustersResponse = ListClustersResponse
