# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from _qwak_proto.qwak.execution.v1 import batch_pb2 as qwak_dot_execution_dot_v1_dot_batch__pb2
from _qwak_proto.qwak.execution.v1 import deletion_pb2 as qwak_dot_execution_dot_v1_dot_deletion__pb2
from _qwak_proto.qwak.execution.v1 import streaming_pb2 as qwak_dot_execution_dot_v1_dot_streaming__pb2
from _qwak_proto.qwak.execution.v1 import streaming_aggregation_pb2 as qwak_dot_execution_dot_v1_dot_streaming__aggregation__pb2
from _qwak_proto.qwak.execution.v1 import execution_pb2 as qwak_dot_execution_dot_v1_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/execution/v1/execution_service.proto\x12\x1fqwak.feature.store.execution.v1\x1a qwak/execution/v1/backfill.proto\x1a\x1dqwak/execution/v1/batch.proto\x1a qwak/execution/v1/deletion.proto\x1a!qwak/execution/v1/streaming.proto\x1a-qwak/execution/v1/streaming_aggregation.proto\x1a!qwak/execution/v1/execution.proto\")\n\'ListLastExecutionsForEnvironmentRequest\"\xb5\x02\n(ListLastExecutionsForEnvironmentResponse\x12\x93\x01\n\x1f\x66\x65\x61tureset_id_to_last_execution\x18\x01 \x03(\x0b\x32j.qwak.feature.store.execution.v1.ListLastExecutionsForEnvironmentResponse.FeaturesetIdToLastExecutionEntry\x1as\n FeaturesetIdToLastExecutionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry:\x02\x38\x01\"^\n\x16TriggerBackfillRequest\x12\x44\n\rbackfill_spec\x18\x01 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\"/\n\x17TriggerBackfillResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"1\n\x19GetExecutionStatusRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"h\n\x1aGetExecutionStatusResponse\x12J\n\x10\x65xecution_status\x18\x01 \x01(\x0e\x32\x30.qwak.feature.store.execution.v1.ExecutionStatus\"0\n\x18GetExecutionEntryRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"e\n\x19GetExecutionEntryResponse\x12H\n\x0f\x65xecution_entry\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"i\n\x1dTriggerBatchFeaturesetRequest\x12H\n\x0f\x62\x61tch_ingestion\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.BatchIngestion\"6\n\x1eTriggerBatchFeaturesetResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\":\n!GetRunningExecutionEntriesRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"p\n\"GetRunningExecutionEntriesResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"9\n TriggerFeaturesetDeletionRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"9\n!TriggerFeaturesetDeletionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"<\n#InitPaginationByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"Y\n$InitPaginationByFeaturesetIdResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12\x1b\n\x13max_execution_index\x18\x02 \x01(\x03\"\x81\x01\n#ListExecutionsByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x1b\n\x13max_execution_index\x18\x04 \x01(\x03\"r\n$ListExecutionsByFeaturesetIdResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"\x87\x01\n&TriggerOnlineStreamingIngestionRequest\x12]\n\x1aonline_streaming_ingestion\x18\x01 \x01(\x0b\x32\x39.qwak.feature.store.execution.v1.OnlineStreamingIngestion\"?\n\'TriggerOnlineStreamingIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x8a\x01\n\'TriggerOfflineStreamingIngestionRequest\x12_\n\x1boffline_streaming_ingestion\x18\x01 \x01(\x0b\x32:.qwak.feature.store.execution.v1.OfflineStreamingIngestion\"@\n(TriggerOfflineStreamingIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x9a\x01\n3TriggerRowLevelStreamingAggregationIngestionRequest\x12\x63\n\x13row_level_ingestion\x18\x01 \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.RowLevelStreamingAggregationIngestion\"L\n4TriggerRowLevelStreamingAggregationIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x9f\x01\n5TriggerCompactionStreamingAggregationIngestionRequest\x12\x66\n\x14\x63ompaction_ingestion\x18\x01 \x01(\x0b\x32H.qwak.feature.store.execution.v1.CompactionStreamingAggregationIngestion\"N\n6TriggerCompactionStreamingAggregationIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x86\x01\n*TriggerStreamingAggregationBackfillRequest\x12X\n\x08\x62\x61\x63kfill\x18\x01 \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.StreamingAggregationBackfillIngestion\"C\n+TriggerStreamingAggregationBackfillResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t2\xbc\x13\n\x1c\x46\x65\x61tureStoreExecutionService\x12\x89\x01\n\x14TriggerBatchBackfill\x12\x37.qwak.feature.store.execution.v1.TriggerBackfillRequest\x1a\x38.qwak.feature.store.execution.v1.TriggerBackfillResponse\x12\x99\x01\n\x16TriggerBatchFeatureset\x12>.qwak.feature.store.execution.v1.TriggerBatchFeaturesetRequest\x1a?.qwak.feature.store.execution.v1.TriggerBatchFeaturesetResponse\x12\xb4\x01\n\x1fTriggerOnlineStreamingIngestion\x12G.qwak.feature.store.execution.v1.TriggerOnlineStreamingIngestionRequest\x1aH.qwak.feature.store.execution.v1.TriggerOnlineStreamingIngestionResponse\x12\xb7\x01\n TriggerOfflineStreamingIngestion\x12H.qwak.feature.store.execution.v1.TriggerOfflineStreamingIngestionRequest\x1aI.qwak.feature.store.execution.v1.TriggerOfflineStreamingIngestionResponse\x12\xdb\x01\n,TriggerRowLevelStreamingAggregationIngestion\x12T.qwak.feature.store.execution.v1.TriggerRowLevelStreamingAggregationIngestionRequest\x1aU.qwak.feature.store.execution.v1.TriggerRowLevelStreamingAggregationIngestionResponse\x12\xe1\x01\n.TriggerCompactionStreamingAggregationIngestion\x12V.qwak.feature.store.execution.v1.TriggerCompactionStreamingAggregationIngestionRequest\x1aW.qwak.feature.store.execution.v1.TriggerCompactionStreamingAggregationIngestionResponse\x12\xc0\x01\n#TriggerStreamingAggregationBackfill\x12K.qwak.feature.store.execution.v1.TriggerStreamingAggregationBackfillRequest\x1aL.qwak.feature.store.execution.v1.TriggerStreamingAggregationBackfillResponse\x12\xa2\x01\n\x19TriggerFeaturesetDeletion\x12\x41.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionRequest\x1a\x42.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionResponse\x12\x8d\x01\n\x12GetExecutionStatus\x12:.qwak.feature.store.execution.v1.GetExecutionStatusRequest\x1a;.qwak.feature.store.execution.v1.GetExecutionStatusResponse\x12\x8a\x01\n\x11GetExecutionEntry\x12\x39.qwak.feature.store.execution.v1.GetExecutionEntryRequest\x1a:.qwak.feature.store.execution.v1.GetExecutionEntryResponse\x12\xa5\x01\n\x1aGetRunningExecutionEntries\x12\x42.qwak.feature.store.execution.v1.GetRunningExecutionEntriesRequest\x1a\x43.qwak.feature.store.execution.v1.GetRunningExecutionEntriesResponse\x12\xab\x01\n\x1cInitPaginationByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdResponse\x12\xab\x01\n\x1cListExecutionsByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdResponse\x12\xb7\x01\n ListLastExecutionsForEnvironment\x12H.qwak.feature.store.execution.v1.ListLastExecutionsForEnvironmentRequest\x1aI.qwak.feature.store.execution.v1.ListLastExecutionsForEnvironmentResponseB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.execution_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY._options = None
  _LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY._serialized_options = b'8\001'
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTREQUEST']._serialized_start=294
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTREQUEST']._serialized_end=335
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE']._serialized_start=338
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE']._serialized_end=647
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY']._serialized_start=532
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY']._serialized_end=647
  _globals['_TRIGGERBACKFILLREQUEST']._serialized_start=649
  _globals['_TRIGGERBACKFILLREQUEST']._serialized_end=743
  _globals['_TRIGGERBACKFILLRESPONSE']._serialized_start=745
  _globals['_TRIGGERBACKFILLRESPONSE']._serialized_end=792
  _globals['_GETEXECUTIONSTATUSREQUEST']._serialized_start=794
  _globals['_GETEXECUTIONSTATUSREQUEST']._serialized_end=843
  _globals['_GETEXECUTIONSTATUSRESPONSE']._serialized_start=845
  _globals['_GETEXECUTIONSTATUSRESPONSE']._serialized_end=949
  _globals['_GETEXECUTIONENTRYREQUEST']._serialized_start=951
  _globals['_GETEXECUTIONENTRYREQUEST']._serialized_end=999
  _globals['_GETEXECUTIONENTRYRESPONSE']._serialized_start=1001
  _globals['_GETEXECUTIONENTRYRESPONSE']._serialized_end=1102
  _globals['_TRIGGERBATCHFEATURESETREQUEST']._serialized_start=1104
  _globals['_TRIGGERBATCHFEATURESETREQUEST']._serialized_end=1209
  _globals['_TRIGGERBATCHFEATURESETRESPONSE']._serialized_start=1211
  _globals['_TRIGGERBATCHFEATURESETRESPONSE']._serialized_end=1265
  _globals['_GETRUNNINGEXECUTIONENTRIESREQUEST']._serialized_start=1267
  _globals['_GETRUNNINGEXECUTIONENTRIESREQUEST']._serialized_end=1325
  _globals['_GETRUNNINGEXECUTIONENTRIESRESPONSE']._serialized_start=1327
  _globals['_GETRUNNINGEXECUTIONENTRIESRESPONSE']._serialized_end=1439
  _globals['_TRIGGERFEATURESETDELETIONREQUEST']._serialized_start=1441
  _globals['_TRIGGERFEATURESETDELETIONREQUEST']._serialized_end=1498
  _globals['_TRIGGERFEATURESETDELETIONRESPONSE']._serialized_start=1500
  _globals['_TRIGGERFEATURESETDELETIONRESPONSE']._serialized_end=1557
  _globals['_INITPAGINATIONBYFEATURESETIDREQUEST']._serialized_start=1559
  _globals['_INITPAGINATIONBYFEATURESETIDREQUEST']._serialized_end=1619
  _globals['_INITPAGINATIONBYFEATURESETIDRESPONSE']._serialized_start=1621
  _globals['_INITPAGINATIONBYFEATURESETIDRESPONSE']._serialized_end=1710
  _globals['_LISTEXECUTIONSBYFEATURESETIDREQUEST']._serialized_start=1713
  _globals['_LISTEXECUTIONSBYFEATURESETIDREQUEST']._serialized_end=1842
  _globals['_LISTEXECUTIONSBYFEATURESETIDRESPONSE']._serialized_start=1844
  _globals['_LISTEXECUTIONSBYFEATURESETIDRESPONSE']._serialized_end=1958
  _globals['_TRIGGERONLINESTREAMINGINGESTIONREQUEST']._serialized_start=1961
  _globals['_TRIGGERONLINESTREAMINGINGESTIONREQUEST']._serialized_end=2096
  _globals['_TRIGGERONLINESTREAMINGINGESTIONRESPONSE']._serialized_start=2098
  _globals['_TRIGGERONLINESTREAMINGINGESTIONRESPONSE']._serialized_end=2161
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONREQUEST']._serialized_start=2164
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONREQUEST']._serialized_end=2302
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONRESPONSE']._serialized_start=2304
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONRESPONSE']._serialized_end=2368
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_start=2371
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_end=2525
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_start=2527
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_end=2603
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_start=2606
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_end=2765
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_start=2767
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_end=2845
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLREQUEST']._serialized_start=2848
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLREQUEST']._serialized_end=2982
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLRESPONSE']._serialized_start=2984
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLRESPONSE']._serialized_end=3051
  _globals['_FEATURESTOREEXECUTIONSERVICE']._serialized_start=3054
  _globals['_FEATURESTOREEXECUTIONSERVICE']._serialized_end=5546
# @@protoc_insertion_point(module_scope)
