"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.analytics.analytics_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    """The query string"""
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___QueryRequest = QueryRequest

class QueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___QueryResponse = QueryResponse

class ExecuteDdlQueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    """The query string"""
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___ExecuteDdlQueryRequest = ExecuteDdlQueryRequest

class ExecuteDdlQueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___ExecuteDdlQueryResponse = ExecuteDdlQueryResponse

class GetQueryResultsPageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    PAGE_ID_FIELD_NUMBER: builtins.int
    MAX_RESULTS_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    page_id: builtins.str
    """ID of the next page"""
    max_results: builtins.int
    """Max results per response (per page)"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
        page_id: builtins.str = ...,
        max_results: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_results", b"max_results", "page_id", b"page_id", "query_id", b"query_id"]) -> None: ...

global___GetQueryResultsPageRequest = GetQueryResultsPageRequest

class GetQueryResultsPageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    NEXT_PAGE_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: qwak.analytics.analytics_pb2.QueryStatus.ValueType
    """The query status"""
    failure_reason: builtins.str
    """Failure message if failed"""
    next_page_id: builtins.str
    """The ID of the next page"""
    @property
    def data(self) -> qwak.analytics.analytics_pb2.ResultData:
        """The result set"""
    def __init__(
        self,
        *,
        status: qwak.analytics.analytics_pb2.QueryStatus.ValueType = ...,
        failure_reason: builtins.str = ...,
        next_page_id: builtins.str = ...,
        data: qwak.analytics.analytics_pb2.ResultData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "failure_reason", b"failure_reason", "next_page_id", b"next_page_id", "status", b"status"]) -> None: ...

global___GetQueryResultsPageResponse = GetQueryResultsPageResponse

class GetQueryStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___GetQueryStatusRequest = GetQueryStatusRequest

class GetQueryStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    status: qwak.analytics.analytics_pb2.QueryStatus.ValueType
    """The query status"""
    failure_reason: builtins.str
    """Failure message if failed"""
    def __init__(
        self,
        *,
        status: qwak.analytics.analytics_pb2.QueryStatus.ValueType = ...,
        failure_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "status", b"status"]) -> None: ...

global___GetQueryStatusResponse = GetQueryStatusResponse

class DescribeTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    table_name: builtins.str
    """The table to describe"""
    database_name: builtins.str
    """The database to describe"""
    def __init__(
        self,
        *,
        table_name: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "table_name", b"table_name"]) -> None: ...

global___DescribeTableRequest = DescribeTableRequest

class DescribeTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_NAME_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    table_name: builtins.str
    """The name of the described table"""
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.analytics.analytics_pb2.TableColumn]:
        """List of table columns"""
    def __init__(
        self,
        *,
        table_name: builtins.str = ...,
        columns: collections.abc.Iterable[qwak.analytics.analytics_pb2.TableColumn] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["columns", b"columns", "table_name", b"table_name"]) -> None: ...

global___DescribeTableResponse = DescribeTableResponse

class ListTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListTableRequest = ListTableRequest

class ListTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_NAMES_FIELD_NUMBER: builtins.int
    @property
    def table_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tables"""
    def __init__(
        self,
        *,
        table_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["table_names", b"table_names"]) -> None: ...

global___ListTableResponse = ListTableResponse

class CreateTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_FIELD_NUMBER: builtins.int
    @property
    def table(self) -> qwak.analytics.analytics_pb2.TableDefinition: ...
    def __init__(
        self,
        *,
        table: qwak.analytics.analytics_pb2.TableDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["table", b"table"]) -> None: ...

global___CreateTableRequest = CreateTableRequest

class CreateTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateTableResponse = CreateTableResponse

class GetQueryResultDownloadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> qwak.analytics.analytics_pb2.QueryResultDownloadURLParams:
        """The params to define the query result"""
    def __init__(
        self,
        *,
        params: qwak.analytics.analytics_pb2.QueryResultDownloadURLParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetQueryResultDownloadURLRequest = GetQueryResultDownloadURLRequest

class GetQueryResultDownloadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    """Download url - to download the wanted artifact"""
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url"]) -> None: ...

global___GetQueryResultDownloadURLResponse = GetQueryResultDownloadURLResponse

class OptimizeTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    table_name: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        table_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "table_name", b"table_name"]) -> None: ...

global___OptimizeTableRequest = OptimizeTableRequest

class OptimizeTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___OptimizeTableResponse = OptimizeTableResponse

class CreateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name"]) -> None: ...

global___CreateDatabaseRequest = CreateDatabaseRequest

class CreateDatabaseResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateDatabaseResponse = CreateDatabaseResponse
